@@ -336,8 +336,8 @@ mdirt <- function(data, model, customTheta = NULL, structure = NULL, item.Q = NU
     if((is(model, 'mirt.model') || is.character(model)) && is.null(technical$customTheta))
         stop('customTheta input required when using a mirt.model type input')
     technical$omp <- FALSE
-    mods <- myLapply(1:nruns, function(x, ...) return(ESTIMATION(...)), method=method,
-                     latent.regression=latent.regression, structure=structure,
+    mods <- myLapply(1:nruns, function(x, ...) return(ESTIMATION(...)), progress=verbose,
+                     method=method, latent.regression=latent.regression, structure=structure,
                      data=data, model=model, group=group, itemtype=itemtype, optimizer=optimizer,
                      technical=technical, calcNull=FALSE, GenRandomPars=GenRandomPars, item.Q=item.Q,
                      dentype = 'discrete', verbose=ifelse(nruns > 1L, FALSE, verbose), pars=pars, ...)
